//=============================================================================
// UdpServerQuery_SetGameType
//
// Author: }TCP{Wolf
// Date: 2008-03-29
//
// This is a very simple UdpServerQuery which sets the GameType of your server to
// whatever you like. This allows you to have your server appear in the
// clients browser on a different TAB than it normally would.
//
// USAGE (UT):
// comment this line out in UnrealTournament.ini
// ServerActors=IpServer.UdpServerQuery
// with a ; and insert this line
// ServerActors=SetGameType.UdpServerQuery_SetGameType
// instead. Make sure it is AT THE SAME LOCATION IN INI or it will not work.
//=============================================================================
class UdpServerQuery_SetGameType extends UdpServerQuery;

// preferences
var() config enum SearchStringMatch_TYPE	// WHEN to set
{
	always,		// always set
	partial,	// set if partial match (InStr (CAPS(..) ....)) case-IN-sensitive
	precise		// set if PRECISE match ( == )
} SearchStringMatch;

var() config String SearchString;	// what String to look for in the original GameType
var() config String SetToGameType;	// what String to set the GameType to


// runtime
var String useValue;	// value to be used during runtime


// Preparation, determine if different game type should be reported
event PreBeginPlay()
{
	local String old;
	local bool bDoSet;

	//old = Level.Game.GameName;	// Unreal
	old = GetItemName(string(Level.Game.Class));	// UT !!
	l("Old GameType String: "$old);

	// determine if the GameType being advertised should be changed
	switch(SearchStringMatch)
	{
		case always:	// this one is simple, YES it should be changed
			bDoSet = true;
			break;

		case partial:	// insensitive partial search
			bDoSet = (   (InStr( CAPS(old) , CAPS(SearchString) )) > -1   );
			break;

		case precise:
			bDoSet = (SearchString == old);	// yes if equality
			break;

		default:
			bDoSet = false;
	}

	// do action now or not?
	if (bDoSet)	// yes
	{
		l("Changing GameType to "$SetToGameType);
		//Level.Game.GameName = SetToGameType;	// Unreal
		useValue = SetToGameType;
	}
	else	// no
	{
		l("GameType not changed.");
		useValue = old;
	}

	Super.PreBeginPlay();
}


// convenience log function
function l(String what)
{
	log(what,'UdpServerQuery_SetGameType');
}




// Return a string of important system information.
/*
	}TCP{Wolf:
	This is where the interesting part in UT is, because the UDPServerQuery
	fills the GameType value in this function.
	By overriding it the value can be modified.
*/
function string GetInfo()
{
	local string ResultSet;

	// The server name, i.e.: Bob's Server
	ResultSet = "\\hostname\\"$Level.Game.GameReplicationInfo.ServerName;

	// The short server name
	//ResultSet = ResultSet$"\\shortname\\"$Level.Game.GameReplicationInfo.ShortName;

	// The server port.
	ResultSet = ResultSet$"\\hostport\\"$Level.Game.GetServerPort();

	// (optional) The server IP
	// if (ServerIP != "")
	//	ResultSet = ResultSet$"\\hostip\\"$ServerIP;

	// The map/level title
	ResultSet = ResultSet$"\\maptitle\\"$Level.Title;
	
	// Map name
	ResultSet = ResultSet$"\\mapname\\"$Left(string(Level), InStr(string(Level), "."));

	// The mod or game type
	// BEGIN MODIFICATIONS
	//ResultSet = ResultSet$"\\gametype\\"$GetItemName(string(Level.Game.Class)); // original UT
	ResultSet = ResultSet$"\\gametype\\"$useValue;
	// END MODIFICATIONS

	// The number of players
	ResultSet = ResultSet$"\\numplayers\\"$Level.Game.NumPlayers;

	// The maximum number of players
	ResultSet = ResultSet$"\\maxplayers\\"$Level.Game.MaxPlayers;

	// The game mode: openplaying
	ResultSet = ResultSet$"\\gamemode\\openplaying";

	// The version of this game.
	ResultSet = ResultSet$"\\gamever\\"$Level.EngineVersion;

	// The most recent network compatible version.
	if( MinNetVer >= Int(Level.MinNetVersion) && 
		MinNetVer <= Int(Level.EngineVersion) )
		ResultSet = ResultSet$"\\minnetver\\"$string(MinNetVer);
	else
		ResultSet = ResultSet$"\\minnetver\\"$Level.MinNetVersion;

	ResultSet = ResultSet$Level.Game.GetInfo();

	return ResultSet;
}



defaultproperties
{
	SearchStringMatch=always
	SetToGameType="My Custom GameType"
}
